@@ -185,7 +185,11 @@ gme_file_decode(DecoderClient &client, Path path_fs)
 		LogWarning(gme_domain, gme_err);
 
 	if (length > 0)
-		gme_set_fade(emu, length);
+		gme_set_fade(emu, length
+#if GME_VERSION >= 0x000700
+			     , 8000
+#endif
+			     );
 
 	/* play */
 	DecoderCommand cmd;
