@@ -964,6 +964,12 @@ Player::SongBorder() noexcept
 	if (border_pause) {
 		paused = true;
 		pc.listener.OnBorderPause();
+
+		/* drain all outputs to guarantee the current song is
+		   really being played to the end; without this, the
+		   Pause() call would drop all ring buffers */
+		pc.outputs.Drain();
+
 		pc.outputs.Pause();
 		idle_add(IDLE_PLAYER);
 	}
